==> centreon-engine_1.7.2.orig.tar.gz: centreon-engine-1.7.2/test/broker/mod_compatibility.cc <==
/*
** Copyright 2011-2013 Merethis
**
** This file is part of Centreon Engine.
**
** Centreon Engine is free software: you can redistribute it and/or
** modify it under the terms of the GNU General Public License version 2
** as published by the Free Software Foundation.
**
** Centreon Engine is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
** General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with Centreon Engine. If not, see
** <http://www.gnu.org/licenses/>.
*/

#include <cstring>
#include "com/centreon/engine/nebmods.hh"
#include "test/broker/mod_load.hh"

/**************************************
*                                     *
*           Global Objects            *
*                                     *
**************************************/

// Specify the event broker API version.
NEB_API_VERSION(CURRENT_NEB_API_VERSION)

/**************************************
*                                     *
*         Exported Functions          *
*                                     *
**************************************/

/**
 *  @brief Module exit point.
 *
 *  This function is called when the module gets unloaded by Centreon-Engine.
 *  It will deregister all previously registered callbacks and perform
 *  some shutdown stuff.
 *
 *  @param[in] flags  XXX
 *  @param[in] reason XXX
 *
 *  @return 0 on success, any other value on failure.
 */
extern "C" int nebmodule_deinit(int flags, int reason) {
  (void)flags;
  (void)reason;

  return (0);
}

/**
 *  @brief Module entry point.
 *
 *  This function is called when the module gets loaded by Centreon-Engine. It
 *  will register callbacks to catch events and perform some initialization
 *  stuff like config file parsing, thread creation, ...
 *
 *  @param[in] flags  XXX
 *  @param[in] args   The argument string of the module (shall contain the
 *                    configuration file name).
 *  @param[in] handle The module handle.
 *
 *  @return 0 on success, any other value on failure.
 */
extern "C" int nebmodule_init(int flags, char const* args, void* handle) {
  (void)flags;
  (void)args;

  if (handle == NULL) {
    return (1);
  }

  // Set module informations.
  neb_set_module_info(handle,
		      NEBMODULE_MODINFO_TITLE,
		      MOD_TITLE);
  neb_set_module_info(handle,
		      NEBMODULE_MODINFO_AUTHOR,
		      MOD_AUTHOR);
  neb_set_module_info(handle,
		      NEBMODULE_MODINFO_COPYRIGHT,
		      MOD_COPYRIGHT);
  neb_set_module_info(handle,
		      NEBMODULE_MODINFO_VERSION,
		      MOD_VERSION);
  neb_set_module_info(handle,
		      NEBMODULE_MODINFO_LICENSE,
		      MOD_LICENSE);
  neb_set_module_info(handle,
		      NEBMODULE_MODINFO_DESC,
		      MOD_DESCRIPTION);

  return (0);
}

==> centreon-engine_20.04.13.orig.tar.gz: centreon-engine-20.04.13/test/broker/mod_compatibility.cc <==
/*
** Copyright 2011-2013 Merethis
**
** This file is part of Centreon Engine.
**
** Centreon Engine is free software: you can redistribute it and/or
** modify it under the terms of the GNU General Public License version 2
** as published by the Free Software Foundation.
**
** Centreon Engine is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
** General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with Centreon Engine. If not, see
** <http://www.gnu.org/licenses/>.
*/

#include <cstring>
#include "com/centreon/engine/nebmods.hh"
#include "test/broker/mod_load.hh"

/**************************************
 *                                     *
 *           Global Objects            *
 *                                     *
 **************************************/

// Specify the event broker API version.
NEB_API_VERSION(CURRENT_NEB_API_VERSION)

/**************************************
 *                                     *
 *         Exported Functions          *
 *                                     *
 **************************************/

/**
 *  @brief Module exit point.
 *
 *  This function is called when the module gets unloaded by Centreon-Engine.
 *  It will deregister all previously registered callbacks and perform
 *  some shutdown stuff.
 *
 *  @param[in] flags  XXX
 *  @param[in] reason XXX
 *
 *  @return 0 on success, any other value on failure.
 */
extern "C" int nebmodule_deinit(int flags, int reason) {
  (void)flags;
  (void)reason;

  return (0);
}

/**
 *  @brief Module entry point.
 *
 *  This function is called when the module gets loaded by Centreon-Engine. It
 *  will register callbacks to catch events and perform some initialization
 *  stuff like config file parsing, thread creation, ...
 *
 *  @param[in] flags  XXX
 *  @param[in] args   The argument string of the module (shall contain the
 *                    configuration file name).
 *  @param[in] handle The module handle.
 *
 *  @return 0 on success, any other value on failure.
 */
extern "C" int nebmodule_init(int flags, char const* args, void* handle) {
  (void)flags;
  (void)args;

  if (handle == NULL) {
    return (1);
  }

  // Set module informations.
  neb_set_module_info(handle, NEBMODULE_MODINFO_TITLE, MOD_TITLE);
  neb_set_module_info(handle, NEBMODULE_MODINFO_AUTHOR, MOD_AUTHOR);
  neb_set_module_info(handle, NEBMODULE_MODINFO_COPYRIGHT, MOD_COPYRIGHT);
  neb_set_module_info(handle, NEBMODULE_MODINFO_VERSION, MOD_VERSION);
  neb_set_module_info(handle, NEBMODULE_MODINFO_LICENSE, MOD_LICENSE);
  neb_set_module_info(handle, NEBMODULE_MODINFO_DESC, MOD_DESCRIPTION);

  return (0);
}
